@@ -10,9 +10,11 @@ feature_schema = Schema({
     Optional('depends_on_column'): list,
     Optional('dropout'): float,
     Optional('weights'): dict,
+    Optional('grouped_by'): bool,
     Optional('secondary_type'): And(str, Use(str.lower), lambda s: s in COLUMN_DATA_TYPES.get_attributes().values()),
     Optional('original_type'): And(str, Use(str.lower), lambda s: s in COLUMN_DATA_TYPES.get_attributes().values()),
-    Optional('additional_info'): dict
+    Optional('additional_info'): dict,
+    Optional('group_info'): dict,
 })
 
 mixer_schema = Schema({
