@@ -1,5 +1,7 @@
+from lightwood.encoders.time_series.helpers.common import *
 from lightwood.encoders.time_series.helpers.rnn_helpers import *
 from lightwood.encoders.time_series.helpers.transformer_helpers import *
+from lightwood.constants.lightwood import COLUMN_DATA_TYPES
 from lightwood.helpers.torch import LightwoodAutocast
 from lightwood.encoders.encoder_base import BaseEncoder
 from lightwood.encoders.datetime import DatetimeEncoder
@@ -31,7 +33,9 @@ class TimeSeriesEncoder(BaseEncoder):
         self._eos = 0.0  # end of input sequence -- padding value for batches
         self._n_dims = ts_n_dims
         self._normalizer = None
-        self._target_ar_normalizers = []
+        self._target_ar_normalizers = {}  # dict of normalizers for each grouped-by column per previous_target column
+        self._target_type = None
+        self._group_combinations = None
 
     def setup_nn(self, additional_targets=None):
         """This method must be executed after initializing, else types are unassigned"""
@@ -46,13 +50,17 @@ class TimeSeriesEncoder(BaseEncoder):
 
         if additional_targets:
             for t in additional_targets:
-                if t['original_type'] == 'categorical':
-                    t['normalizer'] = CatNormalizer()
-                    t['normalizer'].prepare(t['data'])
-                    total_dims += len(t['normalizer'].scaler.categories_[0])
+                self._target_ar_normalizers[t['name']] = t['normalizers']
+                self._group_combinations = t['group_combinations']
+
+                # categorical normalizers
+                if t['original_type'] == COLUMN_DATA_TYPES.CATEGORICAL:
+                    self._target_type = COLUMN_DATA_TYPES.CATEGORICAL
+                    total_dims += len(t['normalizers']['__default'].scaler.categories_[0])
+
+                # numerical normalizers
                 else:
-                    t['normalizer'] = MinMaxNormalizer()
-                    t['normalizer'].prepare(t['data'])
+                    self._target_type = COLUMN_DATA_TYPES.NUMERIC
                     total_dims += 1
 
         if self.encoder_class == EncoderRNNNumerical:
@@ -76,6 +84,7 @@ class TimeSeriesEncoder(BaseEncoder):
         self._decoder = DecoderRNNNumerical(output_size=total_dims, hidden_size=dec_hsize).to(self.device)
         self._parameters = list(self._encoder.parameters()) + list(self._decoder.parameters())
         self._optimizer = optim.AdamW(self._parameters, lr=self._learning_rate, weight_decay=1e-4)
+        self._n_dims = total_dims
         self._is_setup = True
 
     def to(self, device, available_devices):
@@ -98,10 +107,8 @@ class TimeSeriesEncoder(BaseEncoder):
         lengths = torch.tensor([len(e) for e in data], dtype=torch.float)
         return out_data, lengths
 
-    def _get_batch(self, source, start, step):
-        # source is an iterable element, we want to get source[i+step] or source[i+end]
-        # If padding is not None, until size `source[i+step]`
-        end = min(start + step, len(source))
+    def _get_batch(self, source, start, end):
+        end = min(end, len(source))
         return source[start:end]
 
     def prepare(self, priming_data, previous_target_data=None, feedback_hoop_function=None, batch_size=256):
@@ -132,15 +139,22 @@ class TimeSeriesEncoder(BaseEncoder):
         if previous_target_data is not None and len(previous_target_data) > 0:
             normalized_tensors = []
             for target_dict in previous_target_data:
-                normalizer = target_dict['normalizer']
-                self._target_ar_normalizers.append(normalizer)
-                data = torch.Tensor(normalizer.encode(target_dict['data'])).to(self.device)
+                if target_dict['original_type'] == COLUMN_DATA_TYPES.NUMERIC:
+                    data = torch.zeros((len(priming_data), lengths_data.max().int().item(), 1))
+                    for group_name, normalizer in target_dict['normalizers'].items():
+                        idxs, subset = get_group_matches(target_dict, normalizer.combination, normalizer.keys)
+                        normalized = normalizer.encode(subset).unsqueeze(-1)
+                        data[idxs, :, :] = normalized
+                else:
+                    # categorical has only one normalizer at all times
+                    normalizer = target_dict['normalizers']['__default']
+                    data = normalizer.encode(target_dict['data'])
+                    if len(data.shape) < 3:
+                        data = data.unsqueeze(-1)  # add feature dimension
                 data[torch.isnan(data)] = 0.0
-                if len(data.shape) < 3:
-                    data = data.unsqueeze(-1)  # add feature dimension
                 normalized_tensors.append(data)
 
-            normalized_data = torch.cat(normalized_tensors, dim=-1)
+            normalized_data = torch.cat(normalized_tensors, dim=-1).to(self.device)
             priming_data = torch.cat([priming_data, normalized_data], dim=-1)
 
         self._encoder.train()
@@ -266,9 +280,34 @@ class TimeSeriesEncoder(BaseEncoder):
         # include autoregressive target data
         ptd = []
         if previous_target_data is not None and len(previous_target_data) > 0:
-            for i, col in enumerate(previous_target_data):
-                normalizer = self._target_ar_normalizers[i]
-                ptd.append(normalizer.encode(col))
+            for i, prev_col_data in enumerate(previous_target_data):
+                # normalize numerical target per group-by
+                if self._target_type == COLUMN_DATA_TYPES.NUMERIC:
+                    tensor = torch.zeros((len(prev_col_data['data']), len(prev_col_data['data'][0]), 1)).to(self.device)
+                    all_idxs = set(range(len(prev_col_data['data'])))
+                    for combination in [c for c in self._group_combinations if c != '__default']:
+                        normalizer = self._target_ar_normalizers[prev_col_data['name']].get(frozenset(combination), None)
+                        if normalizer is None:
+                            normalizer = self._target_ar_normalizers[prev_col_data['name']]['__default']
+                        idxs, subset = get_group_matches(prev_col_data, normalizer.combination, normalizer.keys)
+                        if idxs:
+                            tensor[idxs, :, :] = torch.Tensor(normalizer.encode(subset)).unsqueeze(-1).to(self.device)
+                            all_idxs -= set(idxs)
+
+                    # encode all remaining rows (not belonging to any grouped combination) with default normalizer
+                    if all_idxs:
+                        default_norm = self._target_ar_normalizers[prev_col_data['name']]['__default']
+                        subset = [prev_col_data['data'][idx] for idx in all_idxs]
+                        tensor[list(all_idxs), :, :] = torch.Tensor(default_norm.encode(subset)).unsqueeze(-1).to(self.device)
+                        tensor[torch.isnan(tensor)] = 0.0
+
+                # normalize categorical target
+                else:
+                    normalizer = self._target_ar_normalizers[prev_col_data['name']]['__default']
+                    tensor = normalizer.encode(prev_col_data['data'])
+                    tensor[torch.isnan(tensor)] = 0.0
+
+                ptd.append(tensor)
 
         ret = []
         next = []
